@@ -30,6 +30,7 @@ from torcheval.metrics.classification import (
     MulticlassPrecisionRecallCurve,
     MulticlassRecall,
     MultilabelAccuracy,
+    MultilabelAUPRC,
     MultilabelPrecisionRecallCurve,
     MultilabelRecallAtFixedPrecision,
     TopKMultilabelAccuracy,
@@ -44,7 +45,13 @@ from torcheval.metrics.ranking import (
 )
 from torcheval.metrics.regression import MeanSquaredError, R2Score
 
-from torcheval.metrics.text import Perplexity, WordErrorRate
+from torcheval.metrics.text import (
+    BLEUScore,
+    Perplexity,
+    WordErrorRate,
+    WordInformationLost,
+    WordInformationPreserved,
+)
 from torcheval.metrics.window import (
     WindowedBinaryAUROC,
     WindowedBinaryNormalizedEntropy,
@@ -72,6 +79,7 @@ __all__ = [
     "BinaryPrecisionRecallCurve",
     "BinaryRecall",
     "BinaryRecallAtFixedPrecision",
+    "BLEUScore",
     "Cat",
     "ClickThroughRate",
     "HitRate",
@@ -90,6 +98,7 @@ __all__ = [
     "MulticlassPrecisionRecallCurve",
     "MulticlassRecall",
     "MultilabelAccuracy",
+    "MultilabelAUPRC",
     "MultilabelPrecisionRecallCurve",
     "MultilabelRecallAtFixedPrecision",
     "Perplexity",
@@ -105,4 +114,6 @@ __all__ = [
     "WindowedMeanSquaredError",
     "WindowedWeightedCalibration",
     "WordErrorRate",
+    "WordInformationPreserved",
+    "WordInformationLost",
 ]
