@@ -4,8 +4,10 @@
 # This source code is licensed under the BSD-style license found in the
 # LICENSE file in the root directory of this source tree.
 
+from torcheval.metrics.functional.aggregation.auc import auc
 from torcheval.metrics.functional.aggregation.mean import mean
 from torcheval.metrics.functional.aggregation.sum import sum
 from torcheval.metrics.functional.aggregation.throughput import throughput
 
-__all__ = ["mean", "sum", "throughput"]
+
+__all__ = ["mean", "auc", "sum", "throughput"]
