@@ -10,7 +10,18 @@ import warnings
 from collections import defaultdict, deque
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import Any, Callable, DefaultDict, Deque, Dict, List, Optional, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    DefaultDict,
+    Deque,
+    Dict,
+    List,
+    MutableMapping,
+    Optional,
+    Tuple,
+    Union,
+)
 
 import torch
 from torch.nn.parameter import UninitializedParameter
@@ -69,9 +80,9 @@ class ModuleSummary:
     - Number of parameters
     - Number of trainable parameters
     - Estimated size in bytes
-    - Contains uninitialized parameters
-    - FLOPs for forward (-1 meaning not calculated)
-    - FLOPs for backward (-1 meaning not calculated)
+    - Whether this module contains uninitialized parameters
+    - FLOPs for forward ("?" meaning not calculated)
+    - FLOPs for backward ("?" meaning not calculated)
     - Input shape ("?" meaning not calculated)
     - Output shape ("?" meaning not calculated)
     - Forward elapsed time in ms ("?" meaning not calculated)
@@ -85,8 +96,8 @@ class ModuleSummary:
         self._size_bytes: int = 0
         self._submodule_summaries: Dict[str, "ModuleSummary"] = {}
         self._has_uninitialized_param: bool = False
-        self._flops_forward: int = -1
-        self._flops_backward: int = -1
+        self._flops_forward: Union[TUnknown, int] = _UNKNOWN_SIZE
+        self._flops_backward: Union[TUnknown, int] = _UNKNOWN_SIZE
         self._flops_forward_detail: Dict[str, int] = {}
         self._flops_backward_detail: Dict[str, int] = {}
         self._in_size: Union[TUnknown, List[int]] = _UNKNOWN_SIZE
@@ -96,7 +107,7 @@ class ModuleSummary:
     @property
     def submodule_summaries(self) -> Dict[str, "ModuleSummary"]:
         """
-        A Dict with the names of submodules as keys and corresponding ModuleSummary
+        A Dict with the names of submodules as keys and corresponding :class:`~ModuleSummary`
         objects as values. These can be traversed for visualization.
         """
         return self._submodule_summaries
@@ -135,7 +146,7 @@ class ModuleSummary:
         return self._num_trainable_parameters
 
     @property
-    def flops_forward(self) -> int:
+    def flops_forward(self) -> Union[int, TUnknown]:
         """Returns the total FLOPs for forward calculation using this module."""
         if self.has_uninitialized_param:
             warnings.warn(
@@ -145,7 +156,7 @@ class ModuleSummary:
         return self._flops_forward
 
     @property
-    def flops_backward(self) -> int:
+    def flops_backward(self) -> Union[int, TUnknown]:
         """Returns the total FLOPs for backward calculation using this module."""
         if self.has_uninitialized_param:
             warnings.warn(
@@ -201,7 +212,8 @@ def _get_module_flops_and_activation_sizes(
     module: torch.nn.Module,
     # pyre-ignore
     module_args: Optional[Tuple[Any, ...]] = None,
-    module_kwargs: Optional[Dict[str, Any]] = None,
+    # pyre-ignore
+    module_kwargs: Optional[MutableMapping[str, Any]] = None,
 ) -> _ModuleSummaryData:
     # a mapping from module name to activation size tuple (in_size, out_size)
     activation_sizes: Dict[
@@ -267,7 +279,7 @@ def _get_module_flops_and_activation_sizes(
     forward_time_elapsed_ms = {}
     for module_name in forward_elapsed_times_sec:
         forward_time_elapsed_ms[module_name] = (
-            forward_elapsed_times_sec[module_name] / 1000
+            forward_elapsed_times_sec[module_name] / 1000.0
         )
 
     # Reverting all the changes:
@@ -298,7 +310,8 @@ def get_module_summary(
     module: torch.nn.Module,
     # pyre-ignore
     module_args: Optional[Tuple[Any, ...]] = None,
-    module_kwargs: Optional[Dict[str, Any]] = None,
+    # pyre-ignore
+    module_kwargs: Optional[MutableMapping[str, Any]] = None,
 ) -> ModuleSummary:
     """
     Generate a :class:`~ModuleSummary` object, then assign its values and generate submodule tree.
@@ -423,9 +436,9 @@ def get_summary_table(
     """
     stop_attr: List[str] = []
     # Unpack attributes
-    if module_summary.flops_forward == -1:
+    if module_summary.flops_forward == _UNKNOWN_SIZE:
         stop_attr.append("flops_forward")
-    if module_summary.flops_backward == -1:
+    if module_summary.flops_backward == _UNKNOWN_SIZE:
         stop_attr.append("flops_backward")
     if module_summary.in_size == _UNKNOWN_SIZE:
         stop_attr.append("in_size")
